aboutsummaryrefslogtreecommitdiffstats
path: root/cputemp2maxfreq.h
diff options
context:
space:
mode:
Diffstat (limited to 'cputemp2maxfreq.h')
-rw-r--r--cputemp2maxfreq.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/cputemp2maxfreq.h b/cputemp2maxfreq.h
index 984fabc..31f6da1 100644
--- a/cputemp2maxfreq.h
+++ b/cputemp2maxfreq.h
@@ -17,12 +17,17 @@
#define VALID_INTERVAL_MIN 1
#define VALID_INTERVAL_MAX 30
+// Valid transition delays between 0 and 100000
+#define VALID_TRANS_MIN 0
+#define VALID_TRANS_MAX 100000
+
struct s_cpudata {
- long int min_freq; // CPU's minimum frequency
- long int max_freq; // CPU's maximum frequency
- long int cur_freq; // CPU's current frequency
- long int cur_temp; // CPU's current temperature
- long int scale_max; // Governor's maximum scaling frequency
+ long int min_freq; // CPU's minimum frequency
+ long int max_freq; // CPU's maximum frequency
+ long int cur_freq; // CPU's current frequency
+ long int cur_temp; // CPU's current temperature
+ long int scale_max; // Governor's maximum scaling frequency
+ long int transition_latency; // CPU's transition latency
};
struct s_config {